/**
 * Copyright  2002 Sun Microsystems, Inc. All rights reserved.
 */

package edu.cmu.fantango.ejb;

import java.util.*;
import java.io.*;
import javax.naming.*;
import java.sql.*;
import javax.sql.*;

import edu.cmu.fantango.util.*;

/**
 * A simple stateless bean for the Movie application. This bean implements one
 * business method as declared by the remote interface.
 */
public class CancelEJB implements javax.ejb.SessionBean
{
    private  javax.ejb.SessionContext m_ctx = null;

    /**
     *	Store username
     */
	private String s_Username;

    /**
     *	Store order id
     */
	private String s_OrderID;

    /**
     *	Store showing id
     */
	private String s_ShowingID;

    /**
     *	Store tickets
     */
	private String s_Tickets;

    /**
     *	Parameters the bean needs
     */
	private String[] s_Parameters;

    /**
     *	Parameters the bean needs from session
     */
	private String[] s_SAttributes;

    /**
     *	Store error
     */
	private String s_Error;

    /**
     *	Store current goto page
     */
	private static final String s_Goto = "/Orders.jsp";

    /**
     *	Store table
     */
	private static final String s_OrderTable = "FT_ORDER";

    /**
     *	Store table
     */
	private static final String s_ShowingTable = "FT_SHOWING";


    /**
     * Required by EJB spec.
     */
    public void Cancel ( ) {
    }


	/**
	 *	Initializes Cancel class to store and process
	 *	purchase information from form.
	 *
	 *	@throws java.rmi.RemoteException
	 */
    public void Init ( ) throws java.rmi.RemoteException
    {
		System.out.println ( "::CancelEJB:: (Init)" );
		s_Parameters = new String[3];
		s_Parameters[0] = "cancelorder";
		s_Parameters[1] = "showingorder";
		s_Parameters[2] = "ticketsorder";
		s_SAttributes = new String[1];
		s_SAttributes[0] = "userloggedin";
		s_Error = "&nbsp;";
    }

	/**
	 *	Initializes Cancel class to store and process
	 *	register information from form.
	 *
	 *	@exception Throws java.rmi.RemoteException
	 */
    public void InitParams ( String[] params ) throws java.rmi.RemoteException
    {
		System.out.println ( "::CancelEJB:: (InitParams)" );
		s_OrderID 	= params[0];
		s_ShowingID = params[1];
		s_Tickets 	= params[2];
    }


	/**
	 *	Initializes needed session attributes.
	 *
	 *	@param	sattribs Values to assign to needed parameters
	 *	@throws java.rmi.RemoteException
	 */
    public void InitSAttribs ( String[] sattribs ) throws java.rmi.RemoteException
    {
		System.out.println ( "::CancelEJB:: (InitSAttribs)" );
		s_Username = sattribs[0];
    }


	/**
	 *	Returns array of String parameters for the servlet to get
	 *	from request form fields.
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Array of strings of parameter names
	 */
	public String[] getParameters ( ) throws java.rmi.RemoteException
	{
		System.out.println ( "::CancelEJB:: (getParameters)" );
		return s_Parameters;
	}


	/**
	 *	Returns array of String parameters for the servlet to get
	 *	from the session.
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Array of strings of session names to set
	 */
	public String[] getSAttributes ( ) throws java.rmi.RemoteException
	{
		System.out.println ( "::CancelEJB:: (getSAttributes)" );
		return s_SAttributes;
	}


	/**
	 *	Composes string for SQL order query statement.
	 *
	 *	@returns SQL insert statement to query order
	 */
	private String getOrderQuery ( )
	{
		System.out.println ( "::CancelEJB:: (getOrderQuery)" );
		return "SELECT Cancelled FROM FanTango." + s_OrderTable + " WHERE " +
				"ID = " + s_OrderID + " AND " +
				"Customer = '" + s_Username + "'";
	}


	/**
	 *	Composes string for SQL order insert statement.
	 *
	 *	@returns SQL insert statement to insert into order
	 */
	private String getOrderUpdate ( )
	{
		System.out.println ( "::PurchaseEJB:: (getOrderUpdate)" );
		return "UPDATE FanTango." + s_OrderTable +
				" SET Cancelled = 1, " +
				" Date = now(), Time = now() WHERE" +
				" ID = " + s_OrderID;
	}


	/**
	 *	Composes string for SQL showing update statement.
	 *
	 *	@returns SQL insert statement to update showing table
	 */
	private String getShowingUpdate ( )
	{
		System.out.println ( "::CancelEJB:: (getShowingUpdate)" );
		return "UPDATE FanTango." + s_ShowingTable +
				" SET Sold = Sold - " + s_Tickets + " WHERE " +
				" ID = " + s_ShowingID;
	}


	/**
	 *	Returns error state
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Possible errors encountered
	 */
	public String getError ( ) throws java.rmi.RemoteException
	{
		System.out.println ( "::CancelEJB:: (getError) " + s_Error );
		return s_Error;
	}


	/**
	 *	Returns page to go to
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Page to go to after processing
	 */
	public String getGoto ( ) throws java.rmi.RemoteException
	{
		System.out.println ( "::CancelEJB:: (getGoto) " + s_Goto );
		return s_Goto;
	}


	/**
	 *	Processes stored purchase data.
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Success or failure
	 */
    public boolean process ( ) throws java.rmi.RemoteException
    {
		System.out.println ( "::CancelEJB:: (process) Begin." );
        Connection conn = null;
        Statement stmt = null;
        ResultSet result = null;

        System.out.println ( "::CancelEJB:: (process) Starting Datasource access." );

        try
        {
            conn = DBUtil.getDBConnection ( );
            stmt = conn.createStatement ( );

            result = stmt.executeQuery ( this.getOrderQuery ( ) );
            result.first ( );
			System.out.println ( "::CancelEJB:: (process) Order query executed, query: " + this.getOrderQuery ( ) + ", got " + result.getRow ( ) );
			if ( result.getRow ( ) == 0 )
			{
				System.out.println ( "::CancelEJB:: (process) Order customer/id mismatch." );
				return false;
			}

            result = stmt.executeQuery ( this.getOrderUpdate ( ) );
			System.out.println ( "::CancelEJB:: (process) Order update executed, query: " + this.getOrderUpdate ( ) );
            result = stmt.executeQuery ( this.getShowingUpdate ( ) );
			System.out.println ( "::CancelEJB:: (process) Showing update executed, query: " + this.getShowingUpdate ( ) );
			return true;
        }
        catch ( Exception e )
        {
            e.printStackTrace ( );
        }
		finally
		{
			DBUtil.closeConnection ( conn );
			DBUtil.closeStatement ( stmt );
			DBUtil.closeResultSet ( result );
		}

		System.out.println ( "::CancelEJB:: (process) Undefined error." );
		s_Error = "Undefined error";

        return false;
	}


    /**
     * Sets the session context. Required by EJB spec.
     * @param ctx A SessionContext object.
     */
    public void setSessionContext(javax.ejb.SessionContext ctx) {
        m_ctx = ctx;
    }

    /**
     * Creates a bean. Required by EJB spec.
     * @exception throws CreateException.
     */
    public void ejbCreate() throws java.rmi.RemoteException, javax.ejb.CreateException {
        System.out.println("ejbCreate() on obj " + this);
    }

    /**
     * Removes the bean. Required by EJB spec.
     */
    public void ejbRemove() {
        System.out.println("ejbRemove() on obj " + this);
    }

    /**
     * Loads the state of the bean from secondary storage. Required by EJB spec.
     */
    public void ejbActivate() {
        System.out.println("ejbActivate() on obj " + this);
    }

    /**
     * Serializes the state of the bean to secondary storage. Required by EJB spec.
     */
    public void ejbPassivate() {
        System.out.println("ejbPassivate() on obj " + this);
    }


}
