/**
 * Copyright  2002 Sun Microsystems, Inc. All rights reserved.
 */

package edu.cmu.fantango.ejb;

import java.util.*;
import java.io.*;
import javax.naming.*;
import java.sql.*;
import javax.sql.*;

import edu.cmu.fantango.util.*;

/**
 * A simple stateless bean for the Movie application. This bean implements one
 * business method as declared by the remote interface.
 */
public class MovieEJB implements javax.ejb.SessionBean
{
    private  javax.ejb.SessionContext m_ctx = null;

    /**
     * Required by EJB spec.
     */
    public void Movie() {
    }


    /**
     * SQL statement
     */
    public static final String SQL_movies = "select * from fantango.ft_movie;";


    /**
     * Returns a greeting, based on the time of the day.
     * @return returns a greeting as a string.
     * @exception throws a RemoteException.
     */
    public String getMovies ( ) throws java.rmi.RemoteException
    {
        StringBuffer message = new StringBuffer();
		message.append("Movies available:<br>");

        Connection conn = null;
        Statement stmt = null;
        ResultSet result = null;

        try
        {
			conn = DBUtil.getDBConnection ( );
            stmt = conn.createStatement ( );
            result = stmt.executeQuery ( SQL_movies );

            while ( result.next ( ) )
            {
                message.append ( "<br>" ).append ( result.getString ( 2 ) );
            }

        }
        catch ( Exception e )
        {
            e.printStackTrace ( );
        }
		finally
		{
			DBUtil.closeConnection ( conn );
			DBUtil.closeStatement ( stmt );
			DBUtil.closeResultSet ( result );
		}

        return message.toString();
    }


    /**
     * Returns a greeting, based on the time of the day.
     * @return returns a greeting as a string.
     * @exception throws a RemoteException.
     */
    public String getTime() throws java.rmi.RemoteException
    {
        StringBuffer message = new StringBuffer();
        Calendar calendar = new GregorianCalendar();
        int currentHour = calendar.get(Calendar.HOUR_OF_DAY);
        if(currentHour < 12) message.append("morning");
        else
        {
          if( (currentHour >= 12) &&
            (calendar.get(Calendar.HOUR_OF_DAY) < 18)) message.append("afternoon");
          else message.append("evening");
        }
        return message.toString();
   }


    /**
     * Sets the session context. Required by EJB spec.
     * @param ctx A SessionContext object.
     */
    public void setSessionContext(javax.ejb.SessionContext ctx) {
        m_ctx = ctx;
    }

    /**
     * Creates a bean. Required by EJB spec.
     * @exception throws CreateException.
     */
    public void ejbCreate() throws java.rmi.RemoteException, javax.ejb.CreateException {
        System.out.println("ejbCreate() on obj " + this);
    }

    /**
     * Removes the bean. Required by EJB spec.
     */
    public void ejbRemove() {
        System.out.println("ejbRemove() on obj " + this);
    }

    /**
     * Loads the state of the bean from secondary storage. Required by EJB spec.
     */
    public void ejbActivate() {
        System.out.println("ejbActivate() on obj " + this);
    }

    /**
     * Serializes the state of the bean to secondary storage. Required by EJB spec.
     */
    public void ejbPassivate() {
        System.out.println("ejbPassivate() on obj " + this);
    }
}
