/**
 * Copyright  2002 Sun Microsystems, Inc. All rights reserved.
 */

package edu.cmu.fantango.ejb;

/**
 * Remote interface for the OrdersEJB. The remote interface defines all possible
 * business methods for the bean. These are the methods going tobe invoked remotely
 * by clients, once they have a reference to the remote interface.
 *
 * Clients (MovieServlet, in this case), generally take the help of JNDI to lookup
 * the bean's home interface (OrdersHome, in this case) and then use the home interface
 * to obtain references to the bean's remote interface (Orders, in this case).
 *
 */
public interface Orders extends javax.ejb.EJBObject
{
	/**
	 *	Initializes Orders class to store and process
	 *	showing information.
	 *
	 *	@throws java.rmi.RemoteException
	 */
    public void Init ( ) throws java.rmi.RemoteException;

	/**
	 *	Initializes attributes from session.
	 *
	 *	@param	sattribs Values to assign to needed attributes
	 *	@throws java.rmi.RemoteException
	 */
    public void InitSAttribs ( String[] sattribs ) throws java.rmi.RemoteException;

	/**
	 *	Processes stored orders data.
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Contents to display to interface
	 */
    public String process ( ) throws java.rmi.RemoteException;

	/**
	 *	Returns error state
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Possible errors encountered
	 */
	public String getError ( ) throws java.rmi.RemoteException;

	/**
	 *	Returns page to go to
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Page to go to after processing
	 */
	public String getGoto ( ) throws java.rmi.RemoteException;

	/**
	 *	Returns array of String attributes for the servlet to get
	 *	from session.
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Array of strings of attribute names
	 */
	public String[] getSAttributes ( ) throws java.rmi.RemoteException;

	/**
	 *	Returns array of String attributes that need to be set for the
	 *	session.
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Array of strings of session attributes to set
	 */
	public String[] getSessionAttributes ( ) throws java.rmi.RemoteException;
}
