/**
 * Copyright  2002 Sun Microsystems, Inc. All rights reserved.
 */

package edu.cmu.fantango.ejb;

import java.util.*;
import java.io.*;
import javax.naming.*;
import java.sql.*;
import javax.sql.*;

import edu.cmu.fantango.util.*;

/**
 * A simple stateless bean for the Movie application. This bean implements one
 * business method as declared by the remote interface.
 */
public class RegisterEJB implements javax.ejb.SessionBean
{
    private  javax.ejb.SessionContext m_ctx = null;

    /**
     *	Stored username from form
     */
	private String s_Username;

    /**
     *	Stored password from form
     */
	private String s_Password;

    /**
     *	Stored first name from form
     */
	private String s_FName;

    /**
     *	Stored last name from form
     */
	private String s_LName;

    /**
     *	Stored email from form
     */
	private String s_Email;

    /**
     *	Parameters the bean needs
     */
	private String[] s_Parameters;

    /**
     *	Store error
     */
	private String s_Error;

    /**
     *	Store current goto page
     */
	private String s_Goto;

    /**
     *	Page to load on success
     */
	private static final String s_GotoSuccess = "/index.jsp";

    /**
     *	Page to load on failure
     */
	private static final String s_GotoFailure = "/Register.jsp";

    /**
     *	Table to draw queries from
     */
	private static final String s_Table = "FT_CUSTOMER";

    /**
     * Required by EJB spec.
     */
    public void Register ( ) {
    }


	/**
	 *	Initializes Register class to store and process
	 *	register information from form.
	 *
	 *	@throws java.rmi.RemoteException
	 */
    public void Init ( ) throws java.rmi.RemoteException
    {
		System.out.println ( "::RegisterEJB:: (Init)" );
		s_Parameters = new String[5];
		s_Parameters[0] = "username";
		s_Parameters[1] = "password";
		s_Parameters[2] = "fname";
		s_Parameters[3] = "lname";
		s_Parameters[4] = "email";
		s_Goto = s_GotoSuccess;
		s_Error = "&nbsp;";
    }


	/**
	 *	Initializes Register class to store and process
	 *	register information from form.
	 *
	 *	@exception Throws java.rmi.RemoteException
	 */
    public void InitParams ( String[] params ) throws java.rmi.RemoteException
    {
		System.out.println ( "::RegisterEJB:: (InitParams)" );
		s_Username = params[0];
		s_Password = params[1];
		s_FName = params[2];
		s_LName = params[3];
		s_Email = params[4];
    }


	/**
	 *	Returns array of String parameters for the servlet to get
	 *	from request form fields.
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Array of strings of parameter names
	 */
	public String[] getParameters ( ) throws java.rmi.RemoteException
	{
		System.out.println ( "::RegisterEJB:: (getParameters)" );
		return s_Parameters;
	}


	/**
	 *	Composes string for SQL select statement
	 *
	 *	@returns SQL select statement to check username
	 */
	private String getUsernameCheck ( )
	{
		System.out.println ( "::RegisterEJB:: (getUsernameCheck)" );
		return "SELECT * FROM FanTango." + s_Table + " WHERE " +
				"Username = \"" + s_Username + "\"";
	}


	/**
	 *	Composes string for SQL insert statement
	 *
	 *	@returns SQL insert statement to add user
	 */
	private String getInsert ( )
	{
		System.out.println ( "::RegisterEJB:: (getInsert)" );
        Calendar calendar = new GregorianCalendar ( );
		String date =  calendar.get ( Calendar.YEAR ) + "-"
					 + ( calendar.get ( Calendar.MONTH ) + 1 ) + "-"
					 + calendar.get ( Calendar.DATE ) + " "
					 + calendar.get ( Calendar.HOUR_OF_DAY ) + ":"
					 + calendar.get ( Calendar.MINUTE ) + ":"
					 + calendar.get ( Calendar.SECOND );

		return "INSERT INTO FanTango." + s_Table + " VALUES ( " +
				"'" + s_Username + "', " +
				"'" + s_Password + "', " +
				"'" + s_Email + "', " +
				"'" + s_FName + "', " +
				"'" + s_LName + "', " +
				"'" + date + "', " +
				"1" +
				" )";
	}


	/**
	 *	Returns error state
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Possible errors encountered
	 */
	public String getError ( ) throws java.rmi.RemoteException
	{
		System.out.println ( "::RegisterEJB:: (getError)" + s_Error + "." );
		return s_Error;
	}


	/**
	 *	Returns page to go to
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Page to go to after processing
	 */
	public String getGoto ( ) throws java.rmi.RemoteException
	{
		System.out.println ( "::RegisterEJB:: (getGoto) " + s_Goto );
		return s_Goto;
	}


	/**
	 *	Returns array of String attributes that need to be set for the
	 *	session.
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Array of strings of session attributes to set
	 */
	public String[] getSessionAttributes ( ) throws java.rmi.RemoteException
	{
		System.out.println ( "::RegisterEJB:: (getSessionAttributes)" );
		String[] retSession = new String[2];
		retSession[0] = "userloggedin";
		retSession[1] = s_Username;

		return retSession;
	}


	/**
	 *	Processes stored register data
	 *
	 *	@exception Throws java.rmi.RemoteException
	 *	@returns Success or Failure of the operation
	 */
    public boolean process ( ) throws java.rmi.RemoteException
    {
		System.out.println ( "::RegisterEJB:: (process) Begin." );
        Connection conn = null;
        Statement stmt = null;
        ResultSet result = null;
        ResourceBundle rb = ResourceBundle.getBundle ( "LocalStrings", Locale.getDefault ( ) );

        System.out.println ( "::RegisterEJB:: (process) Starting Datasource access." );

        try
        {
            conn = DBUtil.getDBConnection ( );
            stmt = conn.createStatement ( );
            result = stmt.executeQuery ( this.getUsernameCheck ( ) );
			System.out.println ( "::RegisterEJB:: (process) Username query executed." );

			// Username exists
            if ( result.next ( ) )
            {
				System.out.println ( "::RegisterEJB:: (process) Username exists." );
				s_Goto = s_GotoFailure;
				s_Error = rb.getString ( "invalid_euser" );
				return false;
			}
            // Username doesn't exist, add
            else
            {
				System.out.println ( "::RegisterEJB:: (process) Success, inserting." );
            	result = stmt.executeQuery ( this.getInsert ( ) );
				s_Goto = s_GotoSuccess;
				return true;
			}

        }
        catch ( Exception e )
        {
            e.printStackTrace ( );
        }
		finally
		{
			DBUtil.closeConnection ( conn );
			DBUtil.closeStatement ( stmt );
			DBUtil.closeResultSet ( result );
		}

		System.out.println ( "::RegisterEJB:: (process) Undefined error." );
		s_Goto = s_GotoFailure;
		s_Error = "Undefined error";

        return false;
	}


    /**
     * Sets the session context. Required by EJB spec.
     * @param ctx A SessionContext object.
     */
    public void setSessionContext(javax.ejb.SessionContext ctx) {
        m_ctx = ctx;
    }

    /**
     * Creates a bean. Required by EJB spec.
     * @exception throws CreateException.
     */
    public void ejbCreate() throws java.rmi.RemoteException, javax.ejb.CreateException {
        System.out.println("ejbCreate() on obj " + this);
    }

    /**
     * Removes the bean. Required by EJB spec.
     */
    public void ejbRemove() {
        System.out.println("ejbRemove() on obj " + this);
    }

    /**
     * Loads the state of the bean from secondary storage. Required by EJB spec.
     */
    public void ejbActivate() {
        System.out.println("ejbActivate() on obj " + this);
    }

    /**
     * Serializes the state of the bean to secondary storage. Required by EJB spec.
     */
    public void ejbPassivate() {
        System.out.println("ejbPassivate() on obj " + this);
    }

}
