/**
 * Copyright  2002 Sun Microsystems, Inc. All rights reserved.
 */

package edu.cmu.fantango.ejb;

import java.util.*;
import java.io.*;
import javax.naming.*;
import java.sql.*;
import javax.sql.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
 *	Static class methods for validating initial form contents
 */
public class RegisterValidator
{
	/**
	 *	Validate form contents
	 *
	 *	@exception Throws ServletException and IOException
	 *	@returns Validity of contents
	 */
    public static boolean Validate ( HttpServletRequest request, HttpServletResponse response )
        throws ServletException, IOException
	{
		System.out.println ( "::RegisterValidator:: (Validate)" );
        // Get localstrings.properties strings
        ResourceBundle rb = ResourceBundle.getBundle ( "LocalStrings", Locale.getDefault ( ) );
		String errorMsg = new String ( );

		// Check for omissions and errors
		if ( request.getParameter ( "username" ).length ( ) == 0 )
			errorMsg = rb.getString ( "invalid_user" );
		else if ( request.getParameter ( "password" ).length ( ) == 0 )
			errorMsg = rb.getString ( "invalid_pass" );
		else if ( ! request.getParameter ( "password" ).equals ( request.getParameter ( "passwordrepeat" ) ) )
			errorMsg = rb.getString ( "invalid_passr" );
		else if ( request.getParameter ( "email" ).length ( ) == 0 )
			errorMsg = rb.getString ( "invalid_email" );
		else if ( ! ValidateEmail ( request.getParameter ( "email" ) ) )
			errorMsg = rb.getString ( "invalid_email" );
		else if ( request.getParameter ( "fname" ).length ( ) == 0 )
			errorMsg = rb.getString ( "invalid_fname" );
		else if ( ! ValidateName ( request.getParameter ( "fname" ) ) )
			errorMsg = rb.getString ( "invalid_fname" );
		else if ( request.getParameter ( "lname" ).length ( ) == 0 )
			errorMsg = rb.getString ( "invalid_lname" );
		else if ( ! ValidateName ( request.getParameter ( "lname" ) ) )
			errorMsg = rb.getString ( "invalid_lname" );
		else
		{
			System.out.println ( "::RegisterValidator:: (Validate) Succeeded." );
			errorMsg = "&nbsp;";
			return true;
		}

		System.out.println ( "::RegisterValidator:: (Validate) Failed: " + errorMsg );
		request.setAttribute ( "error", errorMsg );
		request.setAttribute ( "goto", "/Register.jsp" );

		return false;
	}


	/**
	 *	Validate email address
	 *
	 *	@returns Validity of email string
	 */
    private static boolean ValidateEmail ( String email )
    {
		System.out.println ( "::RegisterValidator:: (ValidateEmail)" );
		int at = email.indexOf ( '@' );
		int dot = email.indexOf ( '.' );
		System.out.println ( "Email: |" + email + "|" );
		// Bare minimum is something like a@b.c
		return ( ! ( at == -1 || dot == -1 || at > dot || ( dot - at ) <= 1 || ( email.length ( ) - dot ) <= 1 ) );
	}


	/**
	 *	Validate string
	 *
	 *	@returns Validity of name string
	 */
	private static boolean ValidateName ( String name )
	{
		System.out.println ( "::RegisterValidator:: (ValidateEmail)" );

		for ( int i = 0; i < 10; i++ )
		{
			if ( name.indexOf ( "" + i ) != -1 )
				return false;
		}

		return true;
	}

}
