/**
 * Copyright  2002 Sun Microsystems, Inc. All rights reserved.
 */

package edu.cmu.fantango.ejb;

import java.util.*;
import java.io.*;
import javax.naming.*;
import java.sql.*;
import javax.sql.*;

import edu.cmu.fantango.util.*;

/**
 * A simple stateless bean for the TheaterShowings application. This bean implements one
 * business method as declared by the remote interface.
 */
public class TheaterShowingsEJB implements javax.ejb.SessionBean
{
    private  javax.ejb.SessionContext m_ctx = null;

    /**
     *	Stored theater id from form
     */
	private String s_TheaterID;

    /**
     *	Stored theater name
     */
	private String s_TheaterName;

    /**
     *	Stored theater name
     */
	private String[] s_ShowingRows;

    /**
     *	Parameters the bean needs
     */
	private String[] s_Parameters;

    /**
     *	Store error
     */
	private String s_Error;

    /**
     *	Page to load on success
     */
	private static final String s_Goto = "/SearchTheaters.jsp";


    /**
     * Required by EJB spec.
     */
    public void TheaterShowings ( ) {
    }


	/**
	 *	Initializes Theater Showing class to store and process
	 *	theater showing information.
	 *
	 *	@throws java.rmi.RemoteException
	 */
    public void Init ( ) throws java.rmi.RemoteException
    {
		System.out.println ( "::TheaterShowingsEJB:: (Init)" );
		s_Parameters = new String[1];
		s_Parameters[0] = "TheaterID";
		s_Error = "&nbsp;";
    }


	/**
	 *	Initializes parameters from forms (via request)
	 *
	 *	@param	params Values to assign to needed parameters
	 *	@throws java.rmi.RemoteException
	 */
    public void InitParams ( String[] params ) throws java.rmi.RemoteException
    {
		System.out.println ( "::TheaterShowingsEJB:: (InitParams)" );
		s_TheaterID = params[0];
    }


	/**
	 *	Returns array of String parameters for the servlet to get
	 *	from request form fields.
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Array of strings of parameter names
	 */
	public String[] getParameters ( ) throws java.rmi.RemoteException
	{
		System.out.println ( "::TheaterShowingsEJB:: (getParameters)" );
		return s_Parameters;
	}


	/**
	 *	Returns error state
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Possible errors encountered
	 */
	public String getError ( ) throws java.rmi.RemoteException
	{
		System.out.println ( "::TheaterShowingsEJB:: (getError) " + s_Error );
		return s_Error;
	}


	/**
	 *	Returns page to go to
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Page to go to after processing
	 */
	public String getGoto ( ) throws java.rmi.RemoteException
	{
		System.out.println ( "::TheaterShowingsEJB:: (getGoto) " + s_Goto );
		return s_Goto;
	}


	/**
	 *	Returns array of String attributes that need to be set for the
	 *	session.
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Array of strings of session attributes to set
	 */
	public String[] getSessionAttributes ( ) throws java.rmi.RemoteException
	{
		System.out.println ( "::TheaterShowingsEJB:: (getSessionAttributes)" );
		return null;
	}


	/**
	 *	Composes string for SQL purchase query statement.
	 *
	 *	@returns SQL insert statement to query purchase
	 */
	private String getQuery ( )
	{
		System.out.println ( "::TheaterShowingsEJB:: (getQuery)" );
		return "SELECT t.Name, s.ID, m.Title, s.Time, (r.Seats - s.Sold) AS SeatsLeft " +
				"FROM FT_SHOWING s, FT_THEATER t, FT_ROOM r, FT_MOVIE m WHERE " +
				"r.TheaterID = t.ID AND " +
				"s.RoomID = r.ID AND " +
				"s.MovieID = m.ID AND " +
				//"s.Date = now() AND " +
				"t.ID = " + s_TheaterID + " " +
				"ORDER BY m.Title, s.Time";
	}


	/**
	 *	Processes stored theater showing data.
	 *
	 *	@throws java.rmi.RemoteException
	 *	@returns Contents to display to interface
	 */
    public String process ( ) throws java.rmi.RemoteException
    {
		System.out.println ( "::TheaterShowingsEJB:: (process) Begin." );
        StringBuffer message = new StringBuffer();

        Connection conn = null;
        Statement stmt = null;
        ResultSet result = null;

		System.out.println ( "::TheaterShowingsEJB:: (process) Starting Datasource access." );

        try
        {
			conn = DBUtil.getDBConnection ( );
            stmt = conn.createStatement ( );
            result = stmt.executeQuery ( this.getQuery ( ) );
			System.out.println ( "::TheaterShowingsEJB:: (process) Query executed." );
     		ResultSetMetaData rsmd = result.getMetaData();
     		int cols = rsmd.getColumnCount();
			result.last ( );
			int rows = result.getRow ( );

			if ( rows != 0 )
			{
				System.out.println ( "::TheaterShowingsEJB:: (process) Found rows." );
				s_TheaterName = result.getString ( 1 );
				result.first ( );
				s_ShowingRows = new String[rows];
				String delimiter = "__";
				int i, j;
				j = 0;

				do
				{
					s_ShowingRows[j] = "";
					for ( i = 2; i <= cols; i++ )
						s_ShowingRows[j] = s_ShowingRows[j] + result.getString ( i ) + delimiter;
					++j;
				} while ( result.next ( ) );

				message.append ( this.getFormattedTable ( delimiter ) );
			}
        }
        catch ( Exception e )
        {
            e.printStackTrace ( );
        }
		finally
		{
			DBUtil.closeConnection ( conn );
			DBUtil.closeStatement ( stmt );
			DBUtil.closeResultSet ( result );
		}

		System.out.println ( "::TheaterShowingsEJB:: (process) Returning " + message.toString ( ) );
        return message.toString ( );
    }


	/**
	 *	Returns formatted movie table string
	 *
	 *	@returns HTML code for theater table
	 */
	private String getFormattedTheater ( )
	{
		System.out.println ( "::TheaterShowingsEJB:: (getFormattedTheater)" );
		String retString = new String ( );
		retString = "";

		retString = retString + "<br><table align = center border class = MenuTable width = 600 cellpadding = 3>";
		retString = retString + "<tr>";
		retString = retString + "<td class = TheaterName colspan = 2 align = center>";
		retString = retString + s_TheaterName;
		retString = retString + "</td>";
		retString = retString + "</tr>";

		return retString;
	}


	/**
	 *	Returns formatted movie table string
	 *
     *	@param movie Movie title
	 *	@returns HTML code for movie table
	 */
	private String formatMovie ( String movie )
	{
		System.out.println ( "::TheaterShowingsEJB:: (formatMovie) " + movie );
		String retString = new String ( );
		retString = "";

		retString = retString + "<tr>";
		retString = retString + "<td class = MovieName width = 200 valign = top align = left>";
		retString = retString + movie;
		retString = retString + "</td>";
		retString = retString + "<td valign = top align = left>";

		return retString;
	}


	/**
	 *	Returns formatted table row closing.
	 *
	 *	@returns HTML code for closing a table row
	 */
	private String closeMovieRow ( )
	{
		System.out.println ( "::TheaterShowingsEJB:: (closeMovieRow)" );
		String retString = new String ( );
		retString = "";

		retString = retString + "</td>";
		retString = retString + "</tr>";
		return retString;
	}


	/**
	 *	Returns formatted time string in hh:mm:ss format.
	 *
     *	@param time Time string in hh:mm:ss format
	 *	@returns Time in 12-hour HH:MM am/pm format
	 */
	private String formatTime ( String time )
	{
		System.out.println ( "::TheaterShowingsEJB:: (formatTime)" + time );
		int hour = ( new Integer ( time.substring ( 0, 2 ) ).intValue ( ) );
		if ( hour >= 12 )
		{
			if ( hour > 12 )
				hour -= 12;
			return "" + ( hour < 10 ? "0" : "" ) + hour + time.substring ( 2, 5 ) + "pm";
		}
		else
		{
			if ( hour == 0 )
				hour = 12;
			return "" + ( hour < 10 ? "0" : "" ) + hour + time.substring ( 2, 5 ) + "am";
		}
	}


	/**
	 *	Returns formatted time and seating field.
	 *
     *	@param showingid 	Showing ID
     *	@param time 		Time string
     *	@param seats 		Seat string
	 *	@returns HTML for time and seating
	 */
	private String formatTimeAndSeats ( String showingid, String time, String seats )
	{
		System.out.println ( "::TheaterShowingsEJB:: (formatTimeAndSeats)" );
		String retString = new String ( );
		retString = "";

		if ( ( new Integer ( seats ) ).intValue ( ) > 0 )
		{
			retString = retString + "<a class = \"Main\" href = movie?showing=" + showingid + ">";
			retString = retString + this.formatTime ( time ) + "</a> <span class = MovieTime>(" + seats + ")</a>&nbsp;&nbsp;";
		}
		else
		{
			retString = retString + "<span class = \"SoldOut\">";
			retString = retString + this.formatTime ( time ) + "</span>&nbsp;&nbsp;";
		}

		return retString;
	}


	/**
	 *	Returns page of rows.
	 *
     *	@param delimiter Delimiter string
	 *	@returns HTML page of rows
	 */
	private String getFormattedRows ( String delimiter )
	{
		System.out.println ( "::TheaterShowingsEJB:: (getFormattedRows)");
		String retString = new String ( );
		String currentMovie = new String ( );

		retString = "";
		currentMovie = "";

        for ( int i = 0; i < s_ShowingRows.length; i++ )
        {
			String []row = s_ShowingRows[i].split ( delimiter );

			// New movie row begins
			if ( ! row[1].equals ( currentMovie ) )
			{
				// If it's not the first one, close the row
				if ( i > 0 )
					retString = retString + this.closeMovieRow ( );

				currentMovie = row[1];
				retString = retString + this.formatMovie ( currentMovie );
			}

			// Write time and seating
			retString = retString + this.formatTimeAndSeats ( row[0], row[2], row[3] );
		}

		return retString;
	}


	/**
	 *	Returns full page html code for showing.
	 *
     *	@param delimiter Delimiter string
	 *	@returns HTML code for page
	 */
	private String getFormattedTable ( String delimiter )
	{
		System.out.println ( "::TheaterShowingsEJB:: (getFormattedTable)" );
		return this.getFormattedTheater ( ) + this.getFormattedRows ( delimiter );
	}


    /**
     * Sets the session context. Required by EJB spec.
     * @param ctx A SessionContext object.
     */
    public void setSessionContext(javax.ejb.SessionContext ctx) {
        m_ctx = ctx;
    }

    /**
     * Creates a bean. Required by EJB spec.
     * @exception throws CreateException.
     */
    public void ejbCreate() throws java.rmi.RemoteException, javax.ejb.CreateException {
        System.out.println("ejbCreate() on obj " + this);
    }

    /**
     * Removes the bean. Required by EJB spec.
     */
    public void ejbRemove() {
        System.out.println("ejbRemove() on obj " + this);
    }

    /**
     * Loads the state of the bean from secondary storage. Required by EJB spec.
     */
    public void ejbActivate() {
        System.out.println("ejbActivate() on obj " + this);
    }

    /**
     * Serializes the state of the bean to secondary storage. Required by EJB spec.
     */
    public void ejbPassivate() {
        System.out.println("ejbPassivate() on obj " + this);
    }
}
