/**
 * MovieServlet.java
 */

package edu.cmu.fantango.servlet;

import java.io.*;
import java.util.*;
import javax.servlet.*;
import javax.naming.*;
import javax.servlet.http.*;
import javax.rmi.PortableRemoteObject;
import javax.ejb.*;
import java.sql.*;

import edu.cmu.fantango.ejb.*;
import edu.cmu.fantango.util.*;

/**
 * This servlet is responsible for throwing the html pages for the FanTango application.
 */
public class MovieServlet extends HttpServlet
{
   /**
    *   The doGet method of the servlet. Handles all http GET request.
    *   Required by the servlet specification.
    *
    *   @throws ServletException and IOException.
    */
   public void doGet ( HttpServletRequest request,HttpServletResponse response ) throws ServletException, IOException
   {
        System.out.println ( "::MovieServlet:: (doGet) Begin." );

        HttpSession session = request.getSession ( );
        if ( request.getParameter ( "act" ) != null )
        {
            System.out.println ( "::MovieServlet:: (doGet) act = " + request.getParameter ( "act" ) + "." );

            if ( request.getParameter ( "act" ).equals ( "theaterlist" ) )
                HandleTheaterList ( request, response );
            else if ( request.getParameter ( "act" ).equals ( "movielist" ) )
                HandleMovieForm ( request, response );
            else if ( request.getParameter ( "act" ).equals ( "orderhistory" ) )
                HandleMyOrders ( request, response );
        	else if ( request.getParameter ( "act" ).equals ( "logout" ) )
        		HandleLogout ( request, response );
            else
                { }
        }
        else if ( session.getAttribute ( "showing" ) != null )
        {
            System.out.println ( "::MovieServlet:: (doGet) showing session attribute = " + session.getAttribute ( "showing" ) + "." );
            HandleViewShowing ( request, response );
        }
        else if ( request.getParameter ( "showing" ) != null )
        {
            System.out.println ( "::MovieServlet:: (doGet) showing parameter = " + request.getParameter ( "showing" ) + "." );
            HandleViewShowing ( request, response );
        }
        else if ( request.getParameter ( "cancelorder" ) != null )
        {
            System.out.println ( "::MovieServlet:: (doGet) cancelorder parameter = " + request.getParameter ( "cancelorder" ) + "." );
            HandleCancelOrder ( request, response );
        }

        return;
   }


   /**
    *   The doPost method of the servlet. Handles all http POST request.
    *   Required by the servlet specification.
    *
    *   @exception throws ServletException and IOException.
    */
    public void doPost ( HttpServletRequest request,HttpServletResponse response ) throws ServletException, IOException
    {
        System.out.println ( "::MovieServlet:: (doPost) Begin, Process = " + request.getParameter ( "Process" ) );

		if ( request.getParameter ( "Process" ) == null )
		{
        	System.out.println ( "::MovieServlet:: (Post) Null Process value - check location." );

        	HttpSession session = request.getSession ( );

        	if ( session.getAttribute ( "location" ).equals ( "login" ) )
        		HandleLoginForm ( request, response );
        	else if ( session.getAttribute ( "location" ).equals ( "register" ) )
        		HandleRegisterForm ( request, response );
        	else if ( session.getAttribute ( "location" ).equals ( "searchtheaters" ) )
        		HandleSearchTheaterForm ( request, response );
        	else if ( session.getAttribute ( "location" ).equals ( "showing" ) )
        		HandlePurchaseForm ( request, response );
        	else
        		System.out.println ( "::MovieServlet:: (Post) Unknown null Process value, no known location." );
		}
		else
		{
			System.out.println ( "::MovieServlet:: (Post) Non-null Process value: " + request.getParameter ( "Process" ) );
			if ( request.getParameter ( "Process" ).equals ( "Login" ) )
				HandleLoginForm ( request, response );
			else if ( request.getParameter ( "Process" ).equals ( "Register" ) )
				HandleRegisterForm ( request, response );
			else if ( request.getParameter ( "Process" ).equals ( "Search Theater" ) )
				HandleSearchTheaterForm ( request, response );
			else if ( request.getParameter ( "Process" ).equals ( "Purchase" ) )
				HandlePurchaseForm ( request, response );
			else
				System.out.println ( "::MovieServlet:: (Post) Unknown non-null Process value." );
		}

        return;
    }



   /**
    *   Handles movie list processing.
    *
    *   @exception throws ServletException and IOException.
    */
    public void HandleMovieForm ( HttpServletRequest request, HttpServletResponse response ) throws ServletException, IOException
    {
        System.out.println ( "::MovieServlet:: (HandleMovieForm) Begin." );
        javax.ejb.Handle beanHandle;
        //Movie myMovieBean;
        MovieHome myMovieHome;
        Movie myMovieRemote;

        ResourceBundle rb = ResourceBundle.getBundle("LocalStrings", Locale.getDefault());

        try
        {
            System.out.println ( "::MovieServlet:: (HandleMovieForm) " + rb.getString("looking_up"));
            String JNDIName = "java:ejb/movie";
            System.out.println ( "::MovieServlet:: (HandleMovieForm) " + rb.getString("looking")+": " + JNDIName);

            Object objref = EJBFactory.getEJBHome(JNDIName);
            myMovieHome = (MovieHome)PortableRemoteObject.narrow(objref,
                                            MovieHome.class);
        }
        catch(Exception e)
        {
          System.out.println ( "::MovieServlet:: (HandleMovieForm) " + rb.getString("movie_bean")+" - " +
           rb.getString("is_registered")+"?: " + e.toString());
        return;
        }
        try
        {
            System.out.println ( "::MovieServlet:: (HandleMovieForm) " + rb.getString("creating"));
            myMovieRemote = myMovieHome.create();
        }
        catch(CreateException e)
        {
            System.out.println ( "::MovieServlet:: (HandleMovieForm) " + rb.getString("could_not")+": "+
            e.toString());
            return;
        }

        // Get message from bean
        System.out.println ( "::MovieServlet:: (HandleMovieForm) " + rb.getString("getting"));
        String theMessage = myMovieRemote.getMovies();
        //System.out.println ( "::MovieServlet:: (HandleMovieForm) " + rb.getString("got")+": " + theMessage );

        System.out.println ( "::MovieServlet:: (HandleMovieForm) " + rb.getString("storing"));
        request.setAttribute("message", theMessage);

        System.out.println ( "::MovieServlet:: (HandleMovieForm) " + rb.getString("dispatching"));

        response.setContentType("text/html");
        RequestDispatcher dispatcher;
        dispatcher = getServletContext().getRequestDispatcher("/index.jsp");
        dispatcher.include(request, response);

        return;
    }


   /**
    *   Handles login.
    *
    *   @exception throws ServletException and IOException.
    */
    public void HandleLoginForm ( HttpServletRequest request, HttpServletResponse response ) throws ServletException, IOException
    {
        System.out.println ( "::MovieServlet:: (HandleLoginForm) Begin." );
        if ( ! LoginValidator.Validate ( request, response ) )
        {
            System.out.println ( "::MovieServlet:: (HandleLoginForm) Validator failed." );
            RequestDispatcher dispatcher;
            dispatcher = getServletContext().getRequestDispatcher( ( String ) request.getAttribute ( "goto" ) );
            dispatcher.include(request, response);
            return;
        }

        System.out.println ( "::MovieServlet:: (HandleLoginForm) Validator succeeded." );
        javax.ejb.Handle beanHandle;
        //Movie myMovieBean;
        LoginHome myLoginHome;
        Login myLoginRemote;

        ResourceBundle rb = ResourceBundle.getBundle("LocalStrings", Locale.getDefault());

        try
        {
            System.out.println ( "::MovieServlet:: (HandleLoginForm) " + rb.getString ( "looking_up" ) );
            String JNDIName = "java:ejb/login";
            System.out.println ( "::MovieServlet:: (HandleLoginForm) " + rb.getString ( "looking" ) + ": " + JNDIName );
            Object objref = EJBFactory.getEJBHome(JNDIName);
            myLoginHome = ( LoginHome ) PortableRemoteObject.narrow ( objref, LoginHome.class );
        }
        catch( Exception e )
        {
            System.out.println ( "::MovieServlet:: (HandleLoginForm) " + rb.getString ( "movie_bean" ) + " - " +
                rb.getString ( "is_registered" ) + "?: " + e.toString ( ) );
            return;
        }
        try
        {
            System.out.println ( "::MovieServlet:: (HandleLoginForm) " + rb.getString ( "creating" ) );
            myLoginRemote = myLoginHome.create ( );
        }
        catch ( CreateException e )
        {
            System.out.println ( "::MovieServlet:: (HandleLoginForm) " + rb.getString ( "could_not" ) + ": " +
            e.toString ( ) );
            return;
        }

        System.out.println ( "::MovieServlet:: (HandleLoginForm) " + rb.getString ( "getting" ) );

        // Initializing its default settings
        myLoginRemote.Init ( );

        // Get names of parameters that the bean will need
        String params[] = myLoginRemote.getParameters ( );
        String sendparams[] = new String[params.length];
        for ( int i = 0; i < params.length; i++ )
            sendparams[i] = ( String ) request.getParameter ( params[i] );

        // Send it the values of those parameters
        myLoginRemote.InitParams ( sendparams );

        // Get names of session attributes that the bean will need
        String sattribs[] = myLoginRemote.getSAttributes ( );
        String sendsattribs[] = new String[sattribs.length];
        HttpSession session = request.getSession ( );
        for ( int i = 0; i < sattribs.length; i++ )
            sendsattribs[i] = ( String ) session.getAttribute ( sattribs[i] );

        // Send it the values of those parameters
        myLoginRemote.InitSAttribs ( sendsattribs );

        // If the processing failed
        if ( ! myLoginRemote.process ( ) )
        {
            System.out.println ( "::MovieServlet:: (HandleLoginForm) process Failed: " + myLoginRemote.getError ( ) );
            request.setAttribute ( "error", myLoginRemote.getError ( ) );
            RequestDispatcher dispatcher;
            dispatcher = getServletContext ( ).getRequestDispatcher ( myLoginRemote.getGoto ( ) );
            dispatcher.include ( request, response );
            return;
        }

        System.out.println ( "::MovieServlet:: (HandleLoginForm) process Succeeded." );

        // Any changes for the session need to be grabbed by the servlet
        String[] setSession = myLoginRemote.getSessionAttributes ( );
        if ( setSession != null )
        {
            for ( int i = 0; i < setSession.length; i += 2 )
            {
                session.setAttribute ( setSession[i], setSession[i+1] );
            }

        }

        System.out.println ( "::MovieServlet:: (HandleLoginForm) " + rb.getString ( "dispatching" ) );

        response.setContentType ( "text/html" );
        RequestDispatcher dispatcher;
        if ( session.getAttribute ( "returnto" ) != null )
        {
            System.out.println ( "::MovieServlet:: (HandleLoginForm) Returning to " + ( String ) session.getAttribute ( "returnto" ) );
            dispatcher = getServletContext ( ).getRequestDispatcher ( ( String ) session.getAttribute ( "returnto" ) );
        }
        else
        {
            System.out.println ( "::MovieServlet:: (HandleLoginForm) Going to " + myLoginRemote.getGoto ( ) );
            dispatcher = getServletContext ( ).getRequestDispatcher ( myLoginRemote.getGoto ( ) );
        }
        dispatcher.include ( request, response );
        return;
    }


   /**
    *   Handles registration.
    *
    *   @exception throws ServletException and IOException.
    */
    public void HandleRegisterForm ( HttpServletRequest request, HttpServletResponse response ) throws ServletException, IOException
    {
        System.out.println ( "::MovieServlet:: (HandleRegisterForm) Begin." );
        if ( ! RegisterValidator.Validate ( request, response ) )
        {
            System.out.println ( "::MovieServlet:: (HandleRegisterForm) Validator failed." );
            RequestDispatcher dispatcher;
            dispatcher = getServletContext().getRequestDispatcher( ( String ) request.getAttribute ( "goto" ) );
            dispatcher.include(request, response);
            return;
        }
        System.out.println ( "::MovieServlet:: (HandleRegisterForm) Validator succeeded." );

        javax.ejb.Handle beanHandle;
        //Movie myMovieBean;
        RegisterHome myRegisterHome;
        Register myRegisterRemote;

        ResourceBundle rb = ResourceBundle.getBundle ( "LocalStrings", Locale.getDefault ( ) );

        try
        {
            System.out.println ( "::MovieServlet:: (HandleRegisterForm) " + rb.getString ( "looking_up" ) );
            String JNDIName = "java:ejb/register";
            System.out.println ( "::MovieServlet:: " + rb.getString ( "looking" )+": " + JNDIName );
            Object objref = EJBFactory.getEJBHome(JNDIName);
            myRegisterHome = ( RegisterHome ) PortableRemoteObject.narrow ( objref, RegisterHome.class );
        }
        catch ( Exception e )
        {
            System.out.println ( "::MovieServlet:: (HandleRegisterForm) " + rb.getString ( "movie_bean" ) + " - " +
                rb.getString ( " is_registered" ) + "?: " + e.toString ( ) );
            return;
        }
        try
        {
            System.out.println ( "::MovieServlet:: (HandleRegisterForm) " + rb.getString ( "creating" ) );
            myRegisterRemote = myRegisterHome.create ( );
        }
        catch ( CreateException e )
        {
            System.out.println ( "::MovieServlet:: (HandleRegisterForm) " + rb.getString ( "could_not" ) + ": " + e.toString ( ) );
            return;
        }

        System.out.println ( "::MovieServlet:: (HandleRegisterForm) " + rb.getString ( "getting" ) );

        // Initializing its default settings
        myRegisterRemote.Init ( );

        // Get names of parameters that the bean will need
        String params[] = myRegisterRemote.getParameters ( );
        String sendparams[] = new String[params.length];
        for ( int i = 0; i < params.length; i++ )
            sendparams[i] = ( String ) request.getParameter ( params[i] );

        // Send it the values of those parameters
        myRegisterRemote.InitParams ( sendparams );

        // If the processing failed
        if ( ! myRegisterRemote.process ( ) )
        {
            System.out.println ( "::MovieServlet:: (HandleRegisterForm) process Failed: " + myRegisterRemote.getError ( ) );
            request.setAttribute ( "error", myRegisterRemote.getError ( ) );
            RequestDispatcher dispatcher;
            dispatcher = getServletContext ( ).getRequestDispatcher ( myRegisterRemote.getGoto ( ) );
            dispatcher.include ( request, response );
            return;
        }
        System.out.println ( "::MovieServlet:: (HandleRegisterForm) process Succeeded." );

        // Any changes for the session need to be grabbed by the servlet
        HttpSession session = request.getSession ( );
        String[] setSession = myRegisterRemote.getSessionAttributes ( );
        if ( setSession != null )
        {
            for ( int i = 0; i < setSession.length; i += 2 )
            {
                session.setAttribute ( setSession[i], setSession[i+1] );
            }
        }

        System.out.println ( "::MovieServlet:: (HandleRegisterForm) " + rb.getString ( "dispatching" ) );

        response.setContentType ( "text/html" );
        RequestDispatcher dispatcher;
        if ( session.getAttribute ( "returnto" ) != null )
        {
            System.out.println ( "::MovieServlet:: (HandleRegisterForm) Returning to " + ( String ) session.getAttribute ( "returnto" ) );
            dispatcher = getServletContext ( ).getRequestDispatcher ( ( String )session.getAttribute ( "returnto" ) );
        }
        else
        {
            System.out.println ( "::MovieServlet:: (HandleRegisterForm) Going to " + myRegisterRemote.getGoto ( ) );
            dispatcher = getServletContext ( ).getRequestDispatcher ( myRegisterRemote.getGoto ( ) );
        }
        dispatcher.include ( request, response );
        return;
    }


   /**
    *   Handles grabbing the theater list.
    *
    *   @exception throws ServletException and IOException.
    */
    public void HandleTheaterList ( HttpServletRequest request, HttpServletResponse response ) throws ServletException, IOException
    {
        System.out.println ( "::MovieServlet:: (HandleTheaterList) Begin." );
        ResourceBundle rb = ResourceBundle.getBundle("LocalStrings", Locale.getDefault());

        javax.ejb.Handle beanHandle;
        //Movie myMovieBean;
        TheaterListHome myTheaterListHome;
        TheaterList myTheaterListRemote;

        System.out.println ( "::MovieServlet:: (HandleTheaterList) " + rb.getString ( "movie_servlet" )+ "...");
        System.out.println ( "::MovieServlet:: (HandleTheaterList) " + rb.getString ( "retrieving_jndi" ) );

        try
        {
            System.out.println ( "::MovieServlet:: (HandleTheaterList) " + rb.getString("looking_up"));
            String JNDIName = "java:ejb/theaterlist";
            System.out.println ( "::MovieServlet:: (HandleTheaterList) " + rb.getString("looking")+": " + JNDIName);
            Object objref = EJBFactory.getEJBHome(JNDIName);
            myTheaterListHome = ( TheaterListHome ) PortableRemoteObject.narrow(objref, TheaterListHome.class);
        }
        catch ( Exception e )
        {
			System.out.println ( "::MovieServlet:: (HandleTheaterList) " + rb.getString ( "movie_bean" ) + " - " +
				rb.getString ( "is_registered" ) + "?: " + e.toString ( ) );
			return;
        }
        try
        {
            System.out.println ( "::MovieServlet:: (HandleTheaterList) " + rb.getString("creating"));
            myTheaterListRemote = myTheaterListHome.create();
        }
        catch(CreateException e)
        {
            System.out.println ( "::MovieServlet:: (HandleTheaterList) " + rb.getString("could_not")+": "+
            e.toString());
            return;
        }

        System.out.println ( "::MovieServlet:: (HandleTheaterList) " + rb.getString ( "getting" ) );

		// Initializing its default settings
        myTheaterListRemote.Init ( );

        String theMessage = myTheaterListRemote.process ( );

        System.out.println ( "::MovieServlet:: (HandleTheaterList) " + rb.getString ( "storing" ) );

		// Any changes for the session need to be grabbed by the servlet
		HttpSession session = request.getSession();
        session.setAttribute ( "formselect", theMessage );

        System.out.println ( "::MovieServlet:: (HandleTheaterList) " + rb.getString ( "dispatching" ) );

        response.setContentType ( "text/html" );
        RequestDispatcher dispatcher;
		dispatcher = getServletContext ( ).getRequestDispatcher( myTheaterListRemote.getGoto ( ) );
        System.out.println ( "::MovieServlet:: (HandleTheaterList) Going to " + myTheaterListRemote.getGoto ( ) );
        dispatcher.include ( request, response );

		return;
	}


   /**
    *   Handles the processing of the theater list search.
    *
    *   @exception throws ServletException and IOException.
    */
    public void HandleSearchTheaterForm ( HttpServletRequest request, HttpServletResponse response ) throws ServletException, IOException
    {
        System.out.println ( "::MovieServlet:: (HandleSearchTheaterForm) Begin." );
        javax.ejb.Handle beanHandle;
        //Movie myMovieBean;
        TheaterShowingsHome myTheaterShowingsHome;
        TheaterShowings myTheaterShowingsRemote;

        ResourceBundle rb = ResourceBundle.getBundle("LocalStrings", Locale.getDefault());

        try
        {
            System.out.println ( "::MovieServlet:: (HandleSearchTheaterForm) " + rb.getString("looking_up"));
            String JNDIName = "java:ejb/theatershowings";
            System.out.println ( "::MovieServlet:: (HandleSearchTheaterForm) " + rb.getString("looking")+": " + JNDIName);
            Object objref = EJBFactory.getEJBHome(JNDIName);
            myTheaterShowingsHome = ( TheaterShowingsHome ) PortableRemoteObject.narrow(objref,
                                            TheaterShowingsHome.class);
        }
        catch ( Exception e )
        {
            System.out.println ( "::MovieServlet:: (HandleSearchTheaterForm) " + rb.getString ( "movie_bean" ) + " - " +
                rb.getString ( "is_registered" ) + "?: " + e.toString ( ) );
            return;
        }
        try
        {
            System.out.println ( "::MovieServlet:: (HandleSearchTheaterForm) " + rb.getString("creating"));
            myTheaterShowingsRemote = myTheaterShowingsHome.create();
        }
        catch(CreateException e)
        {
            System.out.println ( "::MovieServlet:: (HandleSearchTheaterForm) " + rb.getString("could_not")+": "+
            e.toString());
            return;
        }

        System.out.println ( "::MovieServlet:: (HandleSearchTheaterForm) " + rb.getString ( "getting" ) );

        // Initializing its default settings
        myTheaterShowingsRemote.Init ( );

        // Get names of parameters that the bean will need
        String params[] = myTheaterShowingsRemote.getParameters ( );
        String sendparams[] = new String[params.length];
        for ( int i = 0; i < params.length; i++ )
            sendparams[i] = ( String ) request.getParameter ( params[i] );

        // Send it the values of those parameters
        myTheaterShowingsRemote.InitParams ( sendparams );

        String theMessage = myTheaterShowingsRemote.process ( );

        //System.out.println ( "::MovieServlet:: (HandleSearchTheaterForm) " + rb.getString ( "got" ) + ": " + theMessage );

        System.out.println ( "::MovieServlet:: (HandleSearchTheaterForm) " + rb.getString ( "storing" ) );
        request.setAttribute ( "theatershowings", theMessage );

        System.out.println ( "::MovieServlet:: (HandleSearchTheaterForm) " + rb.getString ( "dispatching" ) );

        response.setContentType ( "text/html" );
        RequestDispatcher dispatcher;
        dispatcher = getServletContext ( ).getRequestDispatcher( myTheaterShowingsRemote.getGoto ( ) );
        System.out.println ( "::MovieServlet:: (HandleTheaterList) Going to " + myTheaterShowingsRemote.getGoto ( ) );
        dispatcher.include ( request, response );

        return;
    }


   /**
    *   Handles display of showing information.
    *
    *   @exception throws ServletException and IOException.
    */
    public void HandleViewShowing ( HttpServletRequest request, HttpServletResponse response ) throws ServletException, IOException
    {
        System.out.println ( "::MovieServlet:: (HandleViewShowing) Begin." );
        javax.ejb.Handle beanHandle;
        //Movie myMovieBean;
        ShowingHome myShowingHome;
        Showing myShowingRemote;

        ResourceBundle rb = ResourceBundle.getBundle("LocalStrings", Locale.getDefault());

        try
        {
            System.out.println ( "::MovieServlet:: (HandleViewShowing) " + rb.getString("looking_up"));
            String JNDIName = "java:ejb/showing";
            System.out.println ( "::MovieServlet:: (HandleViewShowing) " + rb.getString("looking")+": " + JNDIName);
            Object objref = EJBFactory.getEJBHome ( JNDIName );
            myShowingHome = ( ShowingHome ) PortableRemoteObject.narrow(objref,
                                            ShowingHome.class);
        }
        catch ( Exception e )
        {
            System.out.println ( "::MovieServlet:: (HandleViewShowing) " + rb.getString ( "movie_bean" ) + " - " +
                rb.getString ( "is_registered" ) + "?: " + e.toString ( ) );
            return;
        }
        try
        {
            System.out.println ( "::MovieServlet:: (HandleViewShowing) " + rb.getString("creating"));
            myShowingRemote = myShowingHome.create();
        }
        catch(CreateException e)
        {
            System.out.println ( "::MovieServlet:: (HandleViewShowing) " + rb.getString("could_not")+": "+
            e.toString());
            return;
        }

        System.out.println ( "::MovieServlet:: (HandleViewShowing) " + rb.getString ( "getting" ) );

        // Initializing its default settings
        myShowingRemote.Init ( );

        // Get names of parameters that the bean will need
        String params[] = myShowingRemote.getParameters ( );
        String sendparams[] = new String[params.length];
        for ( int i = 0; i < params.length; i++ )
            sendparams[i] = ( String ) request.getParameter ( params[i] );

        // Send it the values of those parameters
        myShowingRemote.InitParams ( sendparams );

        // Get names of attributes that the bean will need
        String attribs[] = myShowingRemote.getAttributes ( );
        String sendattribs[] = new String[attribs.length];
        for ( int i = 0; i < attribs.length; i++ )
            sendattribs[i] = ( String ) request.getAttribute ( attribs[i] );

        // Send it the values of those attributes
        myShowingRemote.InitAttribs ( sendattribs );

        String theMessage = myShowingRemote.process ( );

        //System.out.println ( "::MovieServlet:: (HandleViewShowing) " + rb.getString ( "got" ) + ": " + theMessage );

        System.out.println ( "::MovieServlet:: (HandleViewShowing) " + rb.getString ( "storing" ) );

        // Any changes for the session need to be grabbed by the servlet
        HttpSession session = request.getSession ( );
        session.setAttribute ( "showing", theMessage );

        System.out.println ( "::MovieServlet:: (HandleViewShowing) " + rb.getString ( "dispatching" ) );

        response.setContentType ( "text/html" );
        RequestDispatcher dispatcher;
        dispatcher = getServletContext ( ).getRequestDispatcher( myShowingRemote.getGoto ( ) );
        System.out.println ( "::MovieServlet:: (HandleTheaterList) Going to " + myShowingRemote.getGoto ( ) );
        dispatcher.include ( request, response );

        return;
    }


   /**
    *   Handles processing of purchase.
    *
    *   @exception throws ServletException and IOException.
    */
    public void HandlePurchaseForm ( HttpServletRequest request, HttpServletResponse response ) throws ServletException, IOException
    {
        System.out.println ( "::MovieServlet:: (HandlePurchaseForm) Begin." );
        ResourceBundle rb = ResourceBundle.getBundle("LocalStrings", Locale.getDefault());

        // First needs to validate that the purchase can go through at all
        String err = PurchaseValidator.Validate ( request, response );
        if ( ! err.equals ( "&nbsp;" ) )
        {
            System.out.println ( "::MovieServlet:: (HandlePurchaseForm) Purchase Validator failed." );
            HandleViewShowing ( request, response );
            return;
        }
        System.out.println ( "::MovieServlet:: (HandlePurchaseForm) Purchase Validator succeeded." );

        // The form works out, so check that they're logged in
        HttpSession session = request.getSession ( );
        if ( ((String)session.getAttribute ( "userloggedin" )) == null )
        {
            System.out.println ( "::MovieServlet:: (HandlePurchaseForm) User not logged in." );
            session.setAttribute ( "returnto", "/Showing.jsp" );
            System.out.println ( "::MovieServlet:: (HandlePurchaseForm) Returnto set to Showing.jsp" );
            request.setAttribute ( "error", rb.getString ( "invalid_needlogin" ) );
            response.setContentType ( "text/html" );
            RequestDispatcher dispatcher;
            dispatcher = getServletContext ( ).getRequestDispatcher( "/Login.jsp" );
            System.out.println ( "::MovieServlet:: (HandlePurchaseForm) Going to Login.jsp" );
            dispatcher.include ( request, response );
            return;
        }

        System.out.println ( "::MovieServlet:: (HandlePurchaseForm) User logged in." );

        javax.ejb.Handle beanHandle;
        //Movie myMovieBean;
        PurchaseHome myPurchaseHome;
        Purchase myPurchaseRemote;

        try
        {
            System.out.println ( "::MovieServlet:: (HandlePurchaseForm) " + rb.getString("looking_up"));
            String JNDIName = "java:ejb/purchase";
            System.out.println ( "::MovieServlet:: (HandlePurchaseForm) " + rb.getString("looking")+": " + JNDIName);
            Object objref = EJBFactory.getEJBHome(JNDIName);
            myPurchaseHome = ( PurchaseHome ) PortableRemoteObject.narrow(objref,
                                            PurchaseHome.class);
        }
        catch ( Exception e )
        {
            System.out.println ( "::MovieServlet:: (HandlePurchaseForm) " + rb.getString ( "movie_bean" ) + " - " +
                rb.getString ( "is_registered" ) + "?: " + e.toString ( ) );
            return;
        }
        try
        {
            System.out.println ( "::MovieServlet:: (HandlePurchaseForm) " + rb.getString("creating"));
            myPurchaseRemote = myPurchaseHome.create();
        }
        catch(CreateException e)
        {
            System.out.println ( "::MovieServlet:: (HandlePurchaseForm) " + rb.getString("could_not")+": "+
            e.toString());
            return;
        }

        System.out.println ( "::MovieServlet:: (HandlePurchaseForm) " + rb.getString ( "getting" ) );

        // Initializing its default settings
        myPurchaseRemote.Init ( );

        // Get names of parameters that the bean will need
        String params[] = myPurchaseRemote.getParameters ( );
        String sendparams[] = new String[params.length];
        for ( int i = 0; i < params.length; i++ )
            sendparams[i] = ( String ) request.getParameter ( params[i] );

        // Send it the values of those parameters
        myPurchaseRemote.InitParams ( sendparams );

        // Get names of attributes that the bean will need
        String sattribs[] = myPurchaseRemote.getSAttributes ( );
        String sendsattribs[] = new String[sattribs.length];
        for ( int i = 0; i < sattribs.length; i++ )
            sendsattribs[i] = ( String ) session.getAttribute ( sattribs[i] );

        // Send it the values of those attributes
        myPurchaseRemote.InitSAttribs ( sendsattribs );

        String theMessage = myPurchaseRemote.process ( );

        //System.out.println ( "::MovieServlet:: (HandlePurchaseForm) " + rb.getString ( "got" ) + ": " + theMessage );

        System.out.println ( "::MovieServlet:: (HandlePurchaseForm) " + rb.getString ( "storing" ) );

        request.setAttribute ( "confirm", theMessage );

        System.out.println ( "::MovieServlet:: (HandlePurchaseForm) " + rb.getString ( "dispatching" ) );

        response.setContentType ( "text/html" );
        RequestDispatcher dispatcher;
        dispatcher = getServletContext ( ).getRequestDispatcher( myPurchaseRemote.getGoto ( ) );
        System.out.println ( "::MovieServlet:: (HandlePurchaseForm) Going to " + myPurchaseRemote.getGoto ( ) );
        dispatcher.include ( request, response );

        return;
    }


   /**
    *   Handles displaying a list of customer orders.
    *
    *   @exception throws ServletException and IOException.
    */
    public void HandleMyOrders ( HttpServletRequest request, HttpServletResponse response ) throws ServletException, IOException
    {
        System.out.println ( "::MovieServlet:: (HandleMyOrders) Begin." );
        ResourceBundle rb = ResourceBundle.getBundle("LocalStrings", Locale.getDefault());

        HttpSession session = request.getSession ( );
        if ( ((String)session.getAttribute ( "userloggedin" )) == null )
        {
            System.out.println ( "::MovieServlet:: (HandleMyOrders) User not logged in." );
            session.setAttribute ( "returnto", "/Orders.jsp" );
            System.out.println ( "::MovieServlet:: (HandleMyOrders) Returnto set to Orders.jsp" );
            request.setAttribute ( "error", rb.getString ( "invalid_needlogin" ) );
            response.setContentType ( "text/html" );
            RequestDispatcher dispatcher;
            dispatcher = getServletContext ( ).getRequestDispatcher( "/Login.jsp" );
            System.out.println ( "::MovieServlet:: (HandleMyOrders) Going to Login.jsp" );
            dispatcher.include ( request, response );
            return;
        }


        javax.ejb.Handle beanHandle;
        //Movie myMovieBean;
        OrdersHome myOrdersHome;
        Orders myOrdersRemote;

        try
        {
            System.out.println ( "::MovieServlet:: (HandleMyOrders) " + rb.getString("looking_up"));
            String JNDIName = "java:ejb/orders";
            System.out.println ( "::MovieServlet:: (HandleMyOrders) " + rb.getString("looking")+": " + JNDIName);
            Object objref = EJBFactory.getEJBHome(JNDIName);
            myOrdersHome = ( OrdersHome ) PortableRemoteObject.narrow(objref,
                                            OrdersHome.class);
        }
        catch ( Exception e )
        {
            System.out.println ( "::MovieServlet:: (HandleMyOrders) " + rb.getString ( "movie_bean" ) + " - " +
                rb.getString ( "is_registered" ) + "?: " + e.toString ( ) );
            return;
        }
        try
        {
            System.out.println ( "::MovieServlet:: (HandleMyOrders) " + rb.getString("creating"));
            myOrdersRemote = myOrdersHome.create();
        }
        catch(CreateException e)
        {
            System.out.println ( "::MovieServlet:: (HandleMyOrders) " + rb.getString("could_not")+": "+
            e.toString());
            return;
        }

        System.out.println ( "::MovieServlet:: (HandleMyOrders) " + rb.getString ( "getting" ) );

        // Initializing its default settings
        myOrdersRemote.Init ( );

        // Get names of attributes that the bean will need
        String sattribs[] = myOrdersRemote.getSAttributes ( );
        String sendsattribs[] = new String[sattribs.length];
        for ( int i = 0; i < sattribs.length; i++ )
            sendsattribs[i] = ( String ) session.getAttribute ( sattribs[i] );

        // Send it the values of those attributes
        myOrdersRemote.InitSAttribs ( sendsattribs );

        String theMessage = myOrdersRemote.process ( );
        if ( theMessage == null )
        {
            System.out.println ( "::MovieServlet:: (HandleMyOrders) No user with that name!" );
            session.setAttribute ( "returnto", "/Orders.jsp" );
            System.out.println ( "::MovieServlet:: (HandleMyOrders) Returnto set to Orders.jsp" );
            request.setAttribute ( "error", rb.getString ( "invalid_userl" ) );
            response.setContentType ( "text/html" );
            RequestDispatcher dispatcher;
            dispatcher = getServletContext ( ).getRequestDispatcher( myOrdersRemote.getGoto ( ) );
            System.out.println ( "::MovieServlet:: (HandleMyOrders) Going to " + myOrdersRemote.getGoto ( ) );
            dispatcher.include ( request, response );
            return;
        }

        //System.out.println ( "::MovieServlet:: (HandleMyOrders) " + rb.getString ( "got" ) + ": " + theMessage );

        System.out.println ( "::MovieServlet:: (HandleMyOrders) " + rb.getString ( "storing" ) );

        // Any changes for the session need to be grabbed by the servlet
        session.setAttribute ( "orders", theMessage );
        session.setAttribute ( "showing", null );

        System.out.println ( "::MovieServlet:: (HandleMyOrders) " + rb.getString ( "dispatching" ) );

        response.setContentType ( "text/html" );
        RequestDispatcher dispatcher;
        dispatcher = getServletContext ( ).getRequestDispatcher( myOrdersRemote.getGoto ( ) );
        System.out.println ( "::MovieServlet:: (HandleMyOrders) Going to " + myOrdersRemote.getGoto ( ) );
        dispatcher.include ( request, response );

        return;
    }


   /**
    *   Handles cancelling of a purchase.
    *
    *   @exception throws ServletException and IOException.
    */
    public void HandleCancelOrder ( HttpServletRequest request, HttpServletResponse response ) throws ServletException, IOException
    {
        System.out.println ( "::MovieServlet:: (HandleCancelOrder) Begin." );

        javax.ejb.Handle beanHandle;
        //Movie myMovieBean;
        CancelHome myCancelHome;
        Cancel myCancelRemote;

        ResourceBundle rb = ResourceBundle.getBundle("LocalStrings", Locale.getDefault());

        try
        {
            System.out.println ( "::MovieServlet:: (HandleCancelOrder) " + rb.getString("looking_up"));
            String JNDIName = "java:ejb/cancel";
            System.out.println ( "::MovieServlet:: (HandleCancelOrder) " + rb.getString("looking")+": " + JNDIName);
            Object objref = EJBFactory.getEJBHome ( JNDIName );
            myCancelHome = ( CancelHome ) PortableRemoteObject.narrow(objref,
                                            CancelHome.class);
        }
        catch ( Exception e )
        {
            System.out.println ( "::MovieServlet:: (HandleCancelOrder) " + rb.getString ( "movie_bean" ) + " - " +
                rb.getString ( "is_registered" ) + "?: " + e.toString ( ) );
            return;
        }
        try
        {
            System.out.println ( "::MovieServlet:: (HandleCancelOrder) " + rb.getString("creating"));
            myCancelRemote = myCancelHome.create();
        }
        catch(CreateException e)
        {
            System.out.println ( "::MovieServlet:: (HandleCancelOrder) " + rb.getString("could_not")+": "+
            e.toString());
            return;
        }

        System.out.println ( "::MovieServlet:: (HandleCancelOrder) " + rb.getString ( "getting" ) );

        // Initializing its default settings
        myCancelRemote.Init ( );

        // Get names of parameters that the bean will need
        String params[] = myCancelRemote.getParameters ( );
        String sendparams[] = new String[params.length];
        for ( int i = 0; i < params.length; i++ )
            sendparams[i] = ( String ) request.getParameter ( params[i] );

        // Send it the values of those parameters
        myCancelRemote.InitParams ( sendparams );

        HttpSession session = request.getSession ( );
        // Get names of attributes that the bean will need
        String sattribs[] = myCancelRemote.getSAttributes ( );
        String sendsattribs[] = new String[sattribs.length];
        for ( int i = 0; i < sattribs.length; i++ )
            sendsattribs[i] = ( String ) session.getAttribute ( sattribs[i] );

        // Send it the values of those attributes
        myCancelRemote.InitSAttribs ( sendsattribs );

        myCancelRemote.process ( );
        session.setAttribute ( "showing", null );
        HandleMyOrders ( request, response );
        return;
    }


   /**
    *	Handles user logout.
	*
    *	@exception throws ServletException and IOException.
    */
    public void HandleLogout ( HttpServletRequest request, HttpServletResponse response ) throws ServletException, IOException
    {
        System.out.println ( "::MovieServlet:: (HandleLogout) Begin." );
		HttpSession session = request.getSession ( );
		session.setAttribute ( "userloggedin", null );

        response.setContentType ( "text/html" );
        RequestDispatcher dispatcher;
		dispatcher = getServletContext ( ).getRequestDispatcher( "/index.jsp" );
        System.out.println ( "::MovieServlet:: (HandleLogout) Going to index.jsp" );
        dispatcher.include ( request, response );

        return;
	}


    /**
    *   Returns the servlet info as a String.
    *   @return returns the servlet info as a String.
    */
    public String getServletInfo ( )
    {
        ResourceBundle rb = ResourceBundle.getBundle ( "LocalStrings", Locale.getDefault ( ) );
        return rb.getString ( "call" ) + ".";
    }

    public static InitialContext getInitialContext() throws NamingException
    {
        Properties p = new Properties();
        p.put(Context.INITIAL_CONTEXT_FACTORY, "org.jnp.interfaces.NamingContextFactory");
        p.put(Context.URL_PKG_PREFIXES, "jboss.naming:org.jnp.interfaces");
        //p.put(Context.PROVIDER_URL, "jnp://localhost:1099");
        p.put(Context.PROVIDER_URL, "jnp:// chess.ece.cmu.edu:1099");
        return new InitialContext(p);
        //may remove these if we find a way to let servlet know where jndi.properties are.
        //we also need to put client/*.jar file to appropriate lib directories of tomcat
        //container we are using. Should we use rb. to get provider URL?
    }
}
